==> knapster-0.9.tar.gz: knapster-0.9/knapster/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Mon Dec  6 23:50:46 CST 1999
    copyright            : (C) 1999-2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "knapster.h"

#include <signal.h>
 
int main(int argc, char *argv[])
{
  KApplication a(argc, argv, "knapster");

  // catch sigpipe signals
  // TODO: test that this will not do anything too drastic
  signal(SIGPIPE,SIG_IGN);

  if (a.isRestored())
  {
    RESTORE(Knapster);
  }
  else {
    Knapster *knapster = new Knapster("Knapster " VERSION);
    a.setMainWidget(knapster);
    knapster->show();

   knapster->loadMP3LibraryPaths();
  }
  return a.exec();
}

==> knapster-0.12.tar.gz: knapster-0.12/knapster/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Mon Dec  6 23:50:46 CST 1999
    copyright            : (C) 1999-2000 by John Donoghue
    email                : donoghue@chariot.net.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "knapster.h"

#include <signal.h>

static void sigpipe_handler(int)
{
  cerr<<"main sigpipe caught!!\n"<<flush;
  return;
}
 
int main(int argc, char *argv[])
{
  KApplication a(argc, argv, "knapster");

  // catch sigpipe signals
  // TODO: test that this will not do anything too drastic

  // DAMN!! - I think it will still crash!!
  signal(SIGPIPE,sigpipe_handler);

  if (a.isRestored())
  {
    RESTORE(Knapster);
  }
  else {
    Knapster *knapster = new Knapster("Knapster " VERSION);
    a.setMainWidget(knapster);
    knapster->show();

   knapster->loadMP3LibraryPaths();
  }
  return a.exec();
}
